``apptainer`` Useful Commands
------------------------------------------

.. list-table:: Useful ``apptainer`` commands
   :header-rows: 1

   * - Description
     - Command
   * - Build production shell with all available CPU cores
     - ``apptainer instance start piel.sif pielapptainer``
   * - Build production shell with all available CPU cores
     - ``apptainer shell instance://pielapptainer``
   * - Build production shell with all available CPU cores
     - ``apptainer build piel.sif piel.def``
   * - Build production shell with all available CPU cores
     - ``apptainer instance stop pielapptainer``
